## v0.4.0 (2025-07-09)

### Feat

- add GetNextAvailableArtifactTool and update tool registration

## v0.3.1 (2025-07-09)

### Refactor

- unify title field to name across models and tools

## v0.3.0 (2025-07-09)

### Feat

- add project overview tool and update available tools list

## v0.2.2 (2025-07-08)

### Refactor

- encapsulate CLI call in main function

## v0.2.1 (2025-07-08)

### Fix

- remove unused import in test_sprint_service.py

## v0.2.0 (2025-07-08)

### Feat

- Enhance Sprint and Epic Tools with validation and message formatting improvements
- **STORY-00C86631**: Implement validate_input abstract method and resolve critical linting issues

### Fix

- Resolve UnboundLocalError in epic tools list_epics
- Resolve TOML parse errors and mypy import issues
- Resolve critical TOML parse errors and type annotation issues
